(function() {
  var defaultMapCenter, getAllDataUrl, getDocumentUrl, getInitialCenter, getLocalStorageMapCenter, getSingleDataUrl, root, transformListOfGeoJsonToGeometryCollection;

  root = this;

  defaultMapCenter = {
    lat: 46.1227,
    lng: -72.6169,
    zoom: 7
  };

  getLocalStorageMapCenter = function() {
    return JSON.parse(localStorage.getItem("mapCenter")) || defaultMapCenter;
  };

  getInitialCenter = function(loc) {
    var ret, x;
    if (loc) {
      loc = (function() {
        var _i, _len, _ref, _results;
        _ref = loc.split(",");
        _results = [];
        for (_i = 0, _len = _ref.length; _i < _len; _i++) {
          x = _ref[_i];
          _results.push(Number(x));
        }
        return _results;
      })();
      if (loc.length !== 3) {
        return getLocalStorageMapCenter();
      }
      ret = {
        lat: loc[0],
        lng: loc[1],
        zoom: loc[2]
      };
      return ret;
    }
    return getLocalStorageMapCenter();
  };

  getSingleDataUrl = function(routeParams) {
    var url;
    url = "/api/" + routeParams.server + "/" + routeParams.database + "/" + routeParams.collection;
    if (routeParams.query) {
      url = "" + url + "/query/" + routeParams.query;
    }
    return "" + url + "/idx/" + (Number(routeParams.idx) - 1);
  };

  getAllDataUrl = function(routeParams) {
    var url;
    url = "/api/" + routeParams.server + "/" + routeParams.database + "/" + routeParams.collection;
    if (routeParams.query) {
      url = "" + url + "/query/" + routeParams.query;
    }
    return "" + url + "/all";
  };

  getDocumentUrl = function(routeParams, id) {
    return "/" + routeParams.server + "/" + routeParams.database + "/" + routeParams.collection + "/_id/" + id;
  };

  transformListOfGeoJsonToGeometryCollection = function(resData, routeParams) {
    var doc, feature, geojson, ret, _i, _len, _ref;
    ret = {
      type: "FeatureCollection",
      features: []
    };
    _ref = resData.document;
    for (_i = 0, _len = _ref.length; _i < _len; _i++) {
      doc = _ref[_i];
      geojson = doc[routeParams.key];
      if (!geojson.properties) {
        geojson.properties = {};
      }
      geojson.properties["_vulture_url_link"] = getDocumentUrl(routeParams, doc._id);
      feature = {
        type: "Feature",
        geometry: geojson,
        properties: geojson.properties
      };
      ret.features.push(feature);
    }
    return ret;
  };

  root.controllers.controller('geojsonmapCtrl', [
    '$scope', '$routeParams', '$location', '$rootScope', 'util', function($scope, $routeParams, $location, $rootScope, util) {
      $scope.geojson = {};
      $scope.geojsonData = {};
      $scope.idx = Number($routeParams.idx);
      $scope.center = getInitialCenter($routeParams.loc);
      $scope.queryObject = $routeParams.query || "{}";
      $scope.$watch('center', function() {
        return localStorage.setItem("mapCenter", JSON.stringify($scope.center));
      });
      $scope.getAggredatedUrl = function() {
        var url;
        url = "#/" + $routeParams.server + "/" + $routeParams.database + "/" + $routeParams.collection + "/idx/all";
        if ($routeParams.query) {
          url = "" + url + "/query/" + $routeParams.query;
        }
        return "" + url + "/geojson/" + $routeParams.key;
      };
      $scope.previousDocumentUrl = function() {
        var url;
        url = "#/" + $routeParams.server + "/" + $routeParams.database + "/" + $routeParams.collection + "/idx/" + ($scope.idx - 1);
        if ($routeParams.query) {
          url = "" + url + "/query/" + $routeParams.query;
        }
        return "" + url + "/geojson/" + $routeParams.key;
      };
      $scope.nextDocumentUrl = function() {
        var url;
        url = "#/" + $routeParams.server + "/" + $routeParams.database + "/" + $routeParams.collection + "/idx/" + ($scope.idx + 1);
        if ($routeParams.query) {
          url = "" + url + "/query/" + $routeParams.query;
        }
        return "" + url + "/geojson/" + $routeParams.key;
      };
      $scope.hasPreviousDocument = function() {
        return $scope.idx > 1;
      };
      $scope.$on("leafletDirectiveMap.geojsonClick", function(ev, featureSelected, leafletEvent) {
        return $location.url(featureSelected.properties._vulture_url_link);
      });
      $scope.setStyleOnFeature = function(feature, element) {
        if (feature.properties && feature.properties.style) {
          element.setStyle(feature.properties.style);
        }
        return element.on({
          click: function(e) {
            return $rootScope.$broadcast("leafletDirectiveMap.geojsonClick", feature, e);
          }
        });
      };
      $scope.initSingleDocument = function() {
        var url;
        url = getSingleDataUrl($routeParams);
        return util.get(url).then(function(res) {
          var geojson;
          geojson = res.data.document[$routeParams.key];
          if (!geojson.properties) {
            geojson.properties = {};
          }
          geojson.properties["_vulture_url_link"] = getDocumentUrl($routeParams, res.data.document._id);
          $scope.meta = res.data.meta;
          return $scope.geojsonData = {
            data: geojson,
            style: geojson.properties.style || void 0,
            resetStyleOnMouseout: true
          };
        });
      };
      $scope.getGoogleMapLink = function() {
        var c;
        c = $scope.center;
        return "https://www.google.ca/maps/@" + c.lat + "," + c.lng + "," + c.zoom + "z";
      };
      $scope.initAllDocuments = function() {
        var url;
        url = getAllDataUrl($routeParams);
        return util.get(url).then(function(res) {
          var geojson;
          $scope.meta = res.data.meta;
          geojson = transformListOfGeoJsonToGeometryCollection(res.data, $routeParams);
          return $scope.geojsonData = {
            data: geojson,
            onEachFeature: $scope.setStyleOnFeature,
            resetStyleOnMouseout: true
          };
        });
      };
      if ($routeParams.idx) {
        $scope.mode = 'single_document';
        $scope.initSingleDocument();
      } else {
        $scope.mode = 'all';
        $scope.initAllDocuments();
      }
      $scope.changeQuery = function(query) {
        var r;
        if (query === "") {
          return "";
        }
        r = $routeParams;
        return $location.path("/" + r.server + "/" + r.database + "/" + r.collection + "/idx/1/query/" + query + "/geojson/" + r.key);
      };
      return $scope.getUrlWithLocation = function() {
        var c, l, rgx;
        c = $scope.center;
        if ($routeParams.loc) {
          l = $location.absUrl();
          rgx = /\/location\/-?\d{0,3}\.?\d*,-?\d{0,3}\.?\d*,\d+/;
          return l.replace(rgx, "/location/" + c.lat + "," + c.lng + "," + c.zoom);
        } else {
          return "" + ($location.absUrl()) + "/location/" + c.lat + "," + c.lng + "," + c.zoom;
        }
      };
    }
  ]);

}).call(this);
